==> aiovantage-0.17.1.tar.gz: aiovantage-0.17.1/src/aiovantage/object_interfaces/object.py <==
"""Interface for querying and controlling system objects."""

import datetime as dt
from dataclasses import dataclass

from .base import Interface


class ObjectInterface(Interface):
    """Interface for querying and controlling system objects."""

    @dataclass
    class PropertyEx:
        """Extended property information."""

        rcode: int
        property: str
        value: str
        size: int

    method_signatures = {
        "Object.GetVID": int,
        "Object.GetController": int,
        "Object.GetType": str,
        "Object.GetName": str,
        "Object.GetModel": str,
        "Object.GetNote": str,
        "Object.GetProperty": int,
        "Object.GetPropertyEx": PropertyEx,
        "Object.IsLocked": bool,
        "Object.IsInterfaceSupported": bool,
        "Object.IsMethodSupported": bool,
        "Object.GetMTime": dt.datetime,
        "Object.GetDName": str,
        "Object.GetArea": int,
    }

    async def get_vid(self, vid: int) -> int:
        """Get the Vantage ID of an object.

        Args:
            vid: The Vantage ID of the object.

        Returns:
            The Vantage ID of the object.
        """
        # INVOKE <id> Object.GetVID
        # -> R:INVOKE <id> <vid> Object.GetVID
        return await self.invoke(vid, "Object.GetVID")

    async def get_controller(self, vid: int) -> int:
        """Get the VID of the controller of an object.

        Args:
            vid: The Vantage ID of the object.

        Returns:
            The VID of the controller of the object.
        """
        # INVOKE <id> Object.GetController
        # -> R:INVOKE <id> <controller> Object.GetController
        return await self.invoke(vid, "Object.GetController")

    async def get_type(self, vid: int) -> str:
        """Get the type of an object.

        Args:
            vid: The Vantage ID of the object.

        Returns:
            The type of the object.
        """
        # INVOKE <id> Object.GetType
        # -> R:INVOKE <id> <type> Object.GetType
        return await self.invoke(vid, "Object.GetType")

    async def get_name(self, vid: int) -> str:
        """Get the name field of an object.

        Args:
            vid: The Vantage ID of the object.

        Returns:
            The name of the object.
        """
        # INVOKE <id> Object.GetName
        # -> R:INVOKE <id> <name> Object.GetName
        return await self.invoke(vid, "Object.GetName")

    async def get_model(self, vid: int) -> str:
        """Get the model field of an object.

        Args:
            vid: The Vantage ID of the object.

        Returns:
            The model of the object.
        """
        # INVOKE <id> Object.GetModel
        # -> R:INVOKE <id> <model> Object.GetModel
        return await self.invoke(vid, "Object.GetModel")

    async def get_note(self, vid: int) -> str:
        """Get the note field of an object.

        Args:
            vid: The Vantage ID of the object.

        Returns:
            The note of the object.
        """
        # INVOKE <id> Object.GetNote
        # -> R:INVOKE <id> <note> Object.GetNote
        return await self.invoke(vid, "Object.GetNote")

    async def get_property(self, vid: int, xpath: str) -> int:
        """Get an integer property of an object.

        Args:
            vid: The Vantage ID of the object.
            xpath: XPath of the property to get, eg: "DName", "Get/Formula/@ReturnType, etc.

        Returns:
            The value of the property.
        """
        # INVOKE <id> Object.GetProperty <xpath>
        # -> R:INVOKE <id> <value> Object.GetProperty <xpath>
        return await self.invoke(vid, "Object.GetProperty", xpath)

    async def get_property_ex(self, vid: int, xpath: str) -> PropertyEx:
        """Get a string property of an object.

        Args:
            vid: The Vantage ID of the object.
            xpath: XPath of the property to get, eg: "DName", "Get/Formula/@ReturnType, etc.

        Returns:
            The value of the property.
        """
        # INVOKE <id> Object.GetPropertyEx <xpath>
        # -> R:INVOKE <id> <value> Object.GetPropertyEx <xpath>
        return await self.invoke(vid, "Object.GetPropertyEx", xpath)

    async def lock(self, vid: int) -> None:
        """Lock an object.

        Args:
            vid: The Vantage ID of the object.
        """
        # INVOKE <id> Object.Lock
        # -> R:INVOKE <id> <rcode> Object.Lock
        await self.invoke(vid, "Object.Lock")

    async def unlock(self, vid: int) -> None:
        """Unlock an object.

        Args:
            vid: The Vantage ID of the object.
        """
        # INVOKE <id> Object.Unlock
        # -> R:INVOKE <id> <rcode> Object.Unlock
        await self.invoke(vid, "Object.Unlock")

    async def is_locked(self, vid: int) -> bool:
        """Check if an object is locked.

        Args:
            vid: The Vantage ID of the object.

        Returns:
            True if the object is locked, False otherwise.
        """
        # INVOKE <id> Object.IsLocked
        # -> R:INVOKE <id> <locked (0/1)> Object.IsLocked
        return await self.invoke(vid, "Object.IsLocked")

    async def is_interface_supported(self, vid: int, iid: int) -> bool:
        """Check if an interface is supported by an object.

        Args:
            vid: The Vantage ID of the object.
            iid: The interface ID to check.

        Returns:
            True if the interface is supported, False otherwise.
        """
        # INVOKE <id> Object.IsInterfaceSupported <iid>
        # -> R:INVOKE <id> <supported (0/1)> Object.IsInterfaceSupported <iid>
        return await self.invoke(vid, "Object.IsInterfaceSupported", iid)

    async def is_method_supported(self, vid: int, iid: int, mid: int) -> bool:
        """Check if a method is supported by an object.

        Args:
            vid: The Vantage ID of the object.
            iid: The interface ID to check.
            mid: The method ID to check.

        Returns:
            True if the method is supported, False otherwise.
        """
        # INVOKE <id> Object.IsMethodSupported <iid> <mid>
        # -> R:INVOKE <id> <supported (0/1)> Object.IsMethodSupported <iid> <mid>
        return await self.invoke(vid, "Object.IsMethodSupported", iid, mid)

    async def set_property(self, vid: int, property: str, value: int) -> None:
        """Set an integer property of an object.

        Args:
            vid: The Vantage ID of the object.
            property: The property to set.
            value: The value to set the property to.
        """
        # INVOKE <id> Object.SetProperty <property> <value>
        # -> R:INVOKE <id> <rcode> Object.SetProperty <property> <value>
        await self.invoke(vid, "Object.SetProperty", property, value)

    async def set_property_ex(self, vid: int, property: str, value: str) -> None:
        """Set a string property of an object.

        Args:
            vid: The Vantage ID of the object.
            property: The property to set.
            value: The value to set the property to.
        """
        # INVOKE <id> Object.SetPropertyEx <property> <value>
        # -> R:INVOKE <id> <rcode> Object.SetPropertyEx <property> <value>
        await self.invoke(vid, "Object.SetPropertyEx", property, value)

    async def get_mtime(self, vid: int) -> dt.datetime:
        """Get the modification time of an object.

        Args:
            vid: The Vantage ID of the object.

        Returns:
            The modification time of the object, as a datetime object.
        """
        # INVOKE <id> Object.GetMTime
        # -> R:INVOKE <id> <mtime> Object.GetMTime
        return await self.invoke(vid, "Object.GetMTime")

    async def get_dname(self, vid: int) -> str:
        """Get the display name of an object.

        Args:
            vid: The Vantage ID of the object.

        Returns:
            The display name of the object.
        """
        # INVOKE <id> Object.GetDName
        # -> R:INVOKE <id> <dname> Object.GetDName
        return await self.invoke(vid, "Object.GetDName")

    async def get_area(self, vid: int) -> int:
        """Get the area of an object.

        Args:
            vid: The Vantage ID of the object.

        Returns:
            The area of the object.
        """
        # INVOKE <id> Object.GetArea
        # -> R:INVOKE <id> <area> Object.GetArea
        return await self.invoke(vid, "Object.GetArea")

==> aiovantage-0.18.0.tar.gz: aiovantage-0.18.0/src/aiovantage/object_interfaces/object.py <==
"""Interface for querying and controlling system objects."""

import datetime as dt
from dataclasses import dataclass

from .base import Interface, method


class ObjectInterface(Interface):
    """Interface for querying and controlling system objects."""

    interface_name = "Object"

    @dataclass
    class PropertyEx:
        """Extended property information."""

        rcode: int
        property: str
        value: str
        size: int

    # Methods
    @method("GetVID")
    async def get_vid(self) -> int:
        """Get the Vantage ID of an object.

        Returns:
            The Vantage ID of the object.
        """
        # INVOKE <id> Object.GetVID
        # -> R:INVOKE <id> <vid> Object.GetVID
        return await self.invoke("Object.GetVID")

    @method("GetController")
    async def get_controller(self) -> int:
        """Get the VID of the controller of an object.

        Returns:
            The VID of the controller of the object.
        """
        # INVOKE <id> Object.GetController
        # -> R:INVOKE <id> <controller> Object.GetController
        return await self.invoke("Object.GetController")

    @method("GetType")
    async def get_type(self) -> str:
        """Get the type of an object.

        Returns:
            The type of the object.
        """
        # INVOKE <id> Object.GetType
        # -> R:INVOKE <id> <type> Object.GetType
        return await self.invoke("Object.GetType")

    @method("GetName")
    async def get_name(self) -> str:
        """Get the name field of an object.

        Returns:
            The name of the object.
        """
        # INVOKE <id> Object.GetName
        # -> R:INVOKE <id> <name> Object.GetName
        return await self.invoke("Object.GetName")

    @method("GetModel")
    async def get_model(self) -> str:
        """Get the model field of an object.

        Returns:
            The model of the object.
        """
        # INVOKE <id> Object.GetModel
        # -> R:INVOKE <id> <model> Object.GetModel
        return await self.invoke("Object.GetModel")

    @method("GetNote")
    async def get_note(self) -> str:
        """Get the note field of an object.

        Returns:
            The note of the object.
        """
        # INVOKE <id> Object.GetNote
        # -> R:INVOKE <id> <note> Object.GetNote
        return await self.invoke("Object.GetNote")

    @method("GetProperty")
    async def get_property(self, xpath: str) -> int:
        """Get an integer property of an object.

        Args:
            xpath: XPath of the property to get, eg: "DName", "Get/Formula/@ReturnType, etc.

        Returns:
            The value of the property.
        """
        # INVOKE <id> Object.GetProperty <xpath>
        # -> R:INVOKE <id> <value> Object.GetProperty <xpath>
        return await self.invoke("Object.GetProperty", xpath)

    @method("GetPropertyEx")
    async def get_property_ex(self, xpath: str) -> PropertyEx:
        """Get a string property of an object.

        Args:
            xpath: XPath of the property to get, eg: "DName", "Get/Formula/@ReturnType, etc.

        Returns:
            The value of the property.
        """
        # INVOKE <id> Object.GetPropertyEx <xpath>
        # -> R:INVOKE <id> <value> Object.GetPropertyEx <xpath>
        return await self.invoke("Object.GetPropertyEx", xpath)

    @method("Lock")
    async def lock(self) -> None:
        """Lock an object."""
        # INVOKE <id> Object.Lock
        # -> R:INVOKE <id> <rcode> Object.Lock
        await self.invoke("Object.Lock")

    @method("Unlock")
    async def unlock(self) -> None:
        """Unlock an object."""
        # INVOKE <id> Object.Unlock
        # -> R:INVOKE <id> <rcode> Object.Unlock
        await self.invoke("Object.Unlock")

    @method("IsLocked")
    async def is_locked(self) -> bool:
        """Check if an object is locked.

        Returns:
            True if the object is locked, False otherwise.
        """
        # INVOKE <id> Object.IsLocked
        # -> R:INVOKE <id> <locked (0/1)> Object.IsLocked
        return await self.invoke("Object.IsLocked")

    @method("IsInterfaceSupported")
    async def is_interface_supported(self, iid: int) -> bool:
        """Check if an interface is supported by an object.

        Args:
            iid: The interface ID to check.

        Returns:
            True if the interface is supported, False otherwise.
        """
        # INVOKE <id> Object.IsInterfaceSupported <iid>
        # -> R:INVOKE <id> <supported (0/1)> Object.IsInterfaceSupported <iid>
        return await self.invoke("Object.IsInterfaceSupported", iid)

    @method("IsMethodSupported")
    async def is_method_supported(self, iid: int, mid: int) -> bool:
        """Check if a method is supported by an object.

        Args:
            iid: The interface ID to check.
            mid: The method ID to check.

        Returns:
            True if the method is supported, False otherwise.
        """
        # INVOKE <id> Object.IsMethodSupported <iid> <mid>
        # -> R:INVOKE <id> <supported (0/1)> Object.IsMethodSupported <iid> <mid>
        return await self.invoke("Object.IsMethodSupported", iid, mid)

    @method("SetProperty")
    async def set_property(self, property: str, value: int) -> None:
        """Set an integer property of an object.

        Args:
            property: The property to set.
            value: The value to set the property to.
        """
        # INVOKE <id> Object.SetProperty <property> <value>
        # -> R:INVOKE <id> <rcode> Object.SetProperty <property> <value>
        await self.invoke("Object.SetProperty", property, value)

    @method("SetPropertyEx")
    async def set_property_ex(self, property: str, value: str) -> None:
        """Set a string property of an object.

        Args:
            property: The property to set.
            value: The value to set the property to.
        """
        # INVOKE <id> Object.SetPropertyEx <property> <value>
        # -> R:INVOKE <id> <rcode> Object.SetPropertyEx <property> <value>
        await self.invoke("Object.SetPropertyEx", property, value)

    @method("GetMTime")
    async def get_m_time(self) -> dt.datetime:
        """Get the modification time of an object.

        Returns:
            The modification time of the object, as a datetime object.
        """
        # INVOKE <id> Object.GetMTime
        # -> R:INVOKE <id> <mtime> Object.GetMTime
        return await self.invoke("Object.GetMTime")

    @method("GetDName")
    async def get_d_name(self) -> str:
        """Get the display name of an object.

        Returns:
            The display name of the object.
        """
        # INVOKE <id> Object.GetDName
        # -> R:INVOKE <id> <dname> Object.GetDName
        return await self.invoke("Object.GetDName")

    @method("GetArea")
    async def get_area(self) -> int:
        """Get the area of an object.

        Returns:
            The area of the object.
        """
        # INVOKE <id> Object.GetArea
        # -> R:INVOKE <id> <area> Object.GetArea
        return await self.invoke("Object.GetArea")
